Learn R Programming

whatifbandit (version 0.3.0)

bandit_invalid: Checks Validity of Thompson sampling probabilities

Description

Checks if the Thompson sampling probabilities either sum arbitrarily close to 0 or if any of them are NA, indicating the direct calculation failed or did not converge.

Usage

bandit_invalid(bandit)

Value

Logical; TRUE if the vector is invalid, FALSE if valid

Arguments

bandit

a numeric vector of Thompson sampling probabilities.