Learn R Programming

whatifbandit (version 0.3.0)

check_prop: Checking for Proportions

Description

Helper to validate_inputs(). This function accepts the user's settings for proportion arguments and checks if they are valid proportions between 0 and 1

Usage

check_prop(...)

Value

Throws an error if any input is not a valid proportion between 0 and 1

Arguments

...

Arguments to check.