Learn R Programming

whatifbandit (version 0.3.0)

verbose_log: Verbose Printer

Description

Shorthand Function for checking verbose and then printing if TRUE

Usage

verbose_log(log, message)

Value

Text output of message to the console when log is TRUE. If log is FALSE, returns nothing.

Arguments

log

Logical; Whether or not to print the message, this will always be the verbose argument passed from higher functions.

message

The message to be printed to screen, as a string.