Learn R Programming

whatifbandit (version 0.3.0)

whatifbandit-package: whatifbandit: Analyzing Randomized Experiments as Multi-Arm Bandits

Description

Simulates the results of completed randomized controlled trials, as if they had been conducted as adaptive Multi-Arm Bandit (MAB) trials instead. Augmented inverse probability weighted estimation (AIPW), outlined by Hadad et al. (2021) tools:::Rd_expr_doi("10.1073/pnas.2014602118"), is used to robustly estimate the probability of success for each treatment arm under the adaptive design. Provides customization options to simulate perfect/imperfect information, stationary/non-stationary bandits, blocked treatment assignments, along with control augmentation, and other hybrid strategies for assigning treatment arms. The methods used in simulation were inspired by Offer-Westort et al. (2021) tools:::Rd_expr_doi("10.1111/ajps.12597").

Arguments

Author

Maintainer: Noah Ochital noahochital@icloud.com (ORCID) [copyright holder]

Other contributors:

See Also