check_posint: Checking If Inputs Are Positive Integers or a Valid String
Description
Helper to validate_inputs(). This function accepts the user's
settings for integer arguments and checks if they are valid positive
integers or are a one of the valid strings for the argument.
Usage
check_posint(...)
Value
Throws an error if any input is not a positive whole number or
a valid string.