Helper to validate_inputs(). This function accepts the user's
settings for proportion arguments and checks if they are valid proportions between 0 and 1
Usage
check_prop(...)
Value
Throws an error if any input is not a valid proportion between 0 and 1