Calculates upper confidence bounds for each treatment arm
# S3 method for ucb1
get_bandit(past_results, conditions, current_period)A named list with 2 elements: a tibble/data.table containing UCB1 and success rate for each condition, and a named numeric vector of assignment probabilities, where the highest UCB1 out of the treatments is assigned 1, and the rest 0.
A tibble/data.table containing summary of prior periods, with
successes, number of observations, and success rates, which is created by get_past_results().
Numeric value of length 1; current period of the adaptive trial simulation.