A modified version of the data set used in https://thelabprojects.dc.gov/benefits-reminder-letter with one additional column added for analysis.
data(tanf)An object of class tbl_df (inherits from tbl, data.frame) with 3517 rows and 21 columns.
Variables are as follows:
Unique, anonymized case identifier.
DC Department of Human Services Center assigned each case.
The assigned letter condition: "No Letter", "Open Appointment", or "Specific Appointment".
Recertification Month.
Date the second (treatment) letter was sent.
Administrative recertification identifier.
Indicates whether letter was returned as undeliverable
PDC Status
Date by which renewal must be completed.
Date the first notice was sent (initial legal communication)
Number of days between the first notice and the recertification due date.
Start date of the recertification period.
End date of recertification period.
Status of recertification process (Pending, Denied, etc.)
Reason for denial if recertification was not approved.
Combined recertification month and year.
Alternate record of first notice date.
Official recertification status from DCAS
Date the recertification was successfully submitted (if applicable).
Binary variable indicating successful recertification based on recert_status (newly added column).